package
Version:
v0.0.0-...-716e23e
Opens a new window with list of versions in this module.
Published: Jan 12, 2019
License: GPL-3.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Server Server `json:"server"`
Mongo Mongo `json:"mongo"`
Webwallet Webwallet `json:"webwallet"`
}
type Mongo struct {
Address string `json:"address"`
Database string `json:"database"`
}
type Satellite struct {
Image string `json:"image"`
Command []string `json:"command"`
RpcPort string `json:"rpcPort"`
Labels map[string]string `json:"labels"`
}
type Server struct {
Address string `json:"address"`
StaticLocation string `json:"staticLocation"`
}
type Watcher struct {
TickSeconds time.Duration `json:"tickSeconds"`
}
type Webwallet struct {
Network string `json:"network"`
InternalResolver bool `json:"internalResolver"`
Satellite Satellite `json:"satellite"`
Watcher Watcher `json:"watcher"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.